==> veracity-source-1.0.0.10517.tar.gz: veracity/src/server_files/ui/activity.js <==
/*
Copyright 2010-2011 SourceGear, LLC

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
 */

//var sgLastActivityMod = false;
var sgActivityEtag = false;
var activityTries = 0;
var _actCsHover = null;
var _actWiHover = null;
var showState = null;

//  build an activity <li /> out of a who/what/when hash
//
function activityItem(activity) {
	var li = $("<li>");

	var p = $("<p>");
	p.addClass('act');
	var a = null;
	
	var hasLink = false;
	if ((!!activity.link) && ($.trim(activity.link) != "")) 
	{
		var ln = sgLinkRoot;
		var repurl = null;

		var matches = activity.link.match(/^(\/repos\/.+?)\//);

		if (matches)
		{
			repurl = sgLinkRoot + matches[1];
		}
		else
			ln += '/repos/' + startRepo;

		ln += activity.link;

		
		
		a = $("<a>").attr("href", ln);
		hasLink = true;

		var matches = activity.link.match(/\/(workitem|changeset).html\?recid=([a-z0-9]+)/);

		if (matches)
		{
			var thing = matches[2];
			var type = matches[1];
			var rels = $('#relations');
			var field = 'other';

			if (type == 'changeset')
				_actCsHover.addHover(a, thing, null, null, repurl);
			else 
				_actWiHover.addHover(a, thing);

			if (type == 'changeset')
			{
				rels = $('#csrelations');
				field = 'commit';
			}

			if (rels)
			{
				li.draggable(
					{
						disabled: ! window.editMode,
						helper: 'clone'
					}
				);

				var rel = {};
				rel[field] = thing;
				li.data('rel', rel );
			}
		}
	} 
	
	if (activity.action != undefined) {
		var act_txt = activity.action + ": ";
		if (hasLink) {
			a.text(act_txt);
			p.append(a);
		}
		else
		{
			p.append(act_txt);
		}
	}

	var el = null;

	if (hasLink && (activity.action == undefined))
	{
		a.text(activity.what);
		el = a;
	}
	else
	{
		var sp = $("<span />").text(activity.what);
		el = sp;
	}

	el.html(vCore.createLinks($.trim(el.text())));
	el.html(el.html().replace(/(\r\n|\n)/g, "<br />"));
	p.append(el);
	
	li.append(p);

	p = $("<p>");
	p.addClass('actsig');

	var d = new Date(parseInt(activity.when));
	var who = activity.email || activity.who || '';
	p.text(_shortWho(who));
	p.append($('<br>'));

	p.append(shortDateTime(d));

	li.append(p);

	return (li);
}

function listActivity(callback) {
	if (callback && (typeof(callback) != 'function'))
		callback = null;

	if (!_showActivity()) {
		if (callback)
			callback();
		window.setTimeout(listActivity, 30000);
		return;
	}

	if (vCore.ajaxCallCount > 0)
	{
		++activityTries;

		if (activityTries < 60)
		{
			if (callback)
				callback();
			window.setTimeout(listActivity, 500);
			return;
		}		
	}

	activityTries = 0;

	var listUrl = sgCurrentRepoUrl + "/activity.json";

	if (_filterActivity() && window.sgUserName)
	{
		listUrl = sgCurrentRepoUrl + "/activity/" + sgUserName + ".json";
		$('#linkactfeed').attr('href', sgCurrentRepoUrl + "/activity/" + sgUserName + ".xml");
	}
	else
		$('#linkactfeed').attr('href', sgCurrentRepoUrl + "/activity.xml");

	vCore.ajax( {
		url : listUrl,
		dataType : 'json',
		cache : true,
		reportErrors: false,

		complete : function(xhr, textStatus) {
			if (callback)
				callback();
			window.setTimeout(listActivity, 30000);
		},

		success : function(data, status, xhr) {
			if ((status != "success") || (!data)) {
				return;
			}

			var uls = $('#activitylist ul');
			var ul = false;

			if (uls.length > 0) {
				ul = $(uls[0]);
			} else {
				ul = $(document.createElement("ul"));
				$('#activitylist').append(ul);
			}

			ul.empty();

			$.each(data, function(index, activity) {
				ul.append( activityItem(activity) );
			});

			_actPager.init('#activitylist', '#activitynav');
		}

	});

}

var _actPager = {
	box : false,
	curTop : 0,

	init : function(ctr, nav) {
		this.box = $(ctr);
		this.nav = $(nav);
		this.box.attr('overflow', 'hidden');
		this.alist = $(ctr + ' ul')[0];

		var pager = this;

		var prevButton = $('#prevActivity');
		var nextButton = $('#nextActivity');

		prevButton.click
		(
			function(e) 
			{
				e.stopPropagation();
				e.preventDefault();
				pager.backUp();
			}
		);

		nextButton.click
		(
			function(e) 
			{
				e.stopPropagation();
				e.preventDefault();

				pager.curTop = nextButton.data('hidingAfter');
				pager.redisplay();
			}
		);

		pager.redisplay();
	},

	redisplay : function() {
		if (! this.box) 
		{ 
			return; 
		}

		var top = this.box.offset().top;
		var scrollTop = $(window).scrollTop();
		var wheight = windowHeight();
		var bheight = wheight - top - 40 + scrollTop;
		var hidingAfter = -1;
		var pager = this;
		var prevButton = $('#prevActivity');
		var nextButton = $('#nextActivity');

		this.box.height(bheight);
		
		$(this.alist).children('li').each(function(idx, li) {
			if ((idx < pager.curTop) || (hidingAfter >= 0)) {
				$(li).hide();
			} else {
				$(li).show();

				var bottom = $(li).offset().top + $(li).height() - top;

				if (bottom >= bheight) {
					$(li).hide();

					if (hidingAfter < 0)
						hidingAfter = idx;
				}
			}
		});

		if (pager.curTop > 0) 
		{
			prevButton.removeAttr('disabled');
			prevButton.find('img').show();
		}
		else
		{
			prevButton.attr('disabled', 'disabled');
			prevButton.find('img').hide();
		}

		if (hidingAfter >= 0) 
		{
			nextButton.removeAttr('disabled');
			nextButton.find('img').show();
			nextButton.data('hidingAfter', hidingAfter);
		}
		else
		{
			nextButton.attr('disabled', 'disabled');
			nextButton.find('img').hide();
		}

		pager.nav.show();
	},

	backUp : function() {
		var top = this.box.offset().top;
		var wheight = windowHeight();
		var bheight = wheight - top - 30;
		var hidingAfter = -1;
		var pager = this;
		var tooFar = false;
		var i;

		this.box.height(bheight);

		var els = $(this.alist).children('li');

		i = this.curTop - 1;
		var canary = $(els[i]);

		this.curTop = 0;

		while ((i > 0) && (!tooFar)) {
			var testee = els[i];
			$(testee).show();

			var bottom = canary.offset().top + canary.height() - top;

			if (bottom >= bheight) {
				this.curTop = i + 1;
				break;
			}

			--i;
		}

		this.redisplay();
	}
};
function _setShowActivity(show) {
	var cname = vCore.getDefaultCookieName();
	vCore.setCookieValueForKey(cname, "showActivity", show, 30);
	
	sgShowActivity = show;

	if (show)
	{
	    $('#menushowactvity').addClass("checked");
		$('#menufilteractivity').show();
	}
	else
	{
	    $('#menushowactvity').removeClass("checked");
		$('#menufilteractivity').hide();
	}

	showState = show;
}

function _showActivity() {
	if (showState === null)
	{
		var cname = vCore.getDefaultCookieName();
		var show = vCore.getCookieValueForKey(cname, "showActivity", false);
		showState = (show && (show != "false")); // cookies stringify
	}
	
	return( showState );
}

function _filterActivity(setfilter) 
{
	var cname = vCore.getDefaultCookieName();
	
	if (setfilter !== undefined)
	{
		vCore.setCookieValueForKey(cname, "filterActivity", setfilter, 30);


		if (setfilter)
			$('#menufilteractivity').addClass("checked");
		else
			$('#menufilteractivity').removeClass("checked");
	}

	var v = vCore.getCookieValueForKey(cname, "filterActivity", false);
	
	return(v && (v != 'false'));
}

function hideActivity() 
{
	$('#activity').width(0);
	$('#activity').hide();
	$('#activity').trigger('resize');
	$('#activity').trigger('repaintGraph');
	showState = false;
}

function displayActivity() 
{
	$('#activity').width(214);
	$('#activity').show();
	$('#activity').trigger('resize');
	$('#activity').trigger('repaintGraph');
	showState = true;
}

function setActivityHeight()
{
	var wHeight = windowHeight();
	var top = $("#activity").offset().top;
	var actHeight = wHeight - top;
	
	// Make sure the size actually changes so we aren't 
	// sending an unnecessary resize event (ahem... IE)
	if (actHeight != $("#activity").height())
	{
		$("#activity").css( { height:actHeight } );
	}
}

$(document).ready(function() {
	setActivityHeight();
	
	$(window).resize(function() { 
		setActivityHeight(); 
		_actPager.redisplay();
	});

	var cleanUpIcon = function()
	{
		var i = $('#imgrefreshact').attr('src', sgStaticLinkRoot + "/img/refresh.png");
	};

	$("#linkrefreshact").click(function(e) {
		e.preventDefault();
		e.stopPropagation();

		var i = $('#imgrefreshact').attr('src', sgStaticLinkRoot + "/img/smallTealProgress.gif");
		listActivity(cleanUpIcon);
	});

	_actCsHover = new hoverControl(fetchChangesetHover);
	_actWiHover = new hoverControl(fetchWorkItemHover);

	if (_showActivity()) {
		displayActivity();
		window.setTimeout(listActivity, 1000);
	} else {
		hideActivity();
	}

});

==> veracity-source-1.1.0.10565.tar.gz: veracity/src/server_files/ui/activity.js <==
/*
Copyright 2010-2011 SourceGear, LLC

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
 */

//var sgLastActivityMod = false;
var sgActivityEtag = false;
var activityTries = 0;
var _actCsHover = null;
var _actWiHover = null;
var showState = null;

//  build an activity <li /> out of a who/what/when hash
//
function activityItem(activity) {
	var li = $("<li>");

	var p = $("<p>");
	p.addClass('act');
	var a = null;
	
	var hasLink = false;
	if ((!!activity.link) && ($.trim(activity.link) != "")) 
	{
		var ln = sgLinkRoot;
		var repurl = null;
		var repo = startRepo;

		var matches = activity.link.match(/^(\/repos\/.+?)\//);

		if (matches)
		{
			var r = matches[1];
			repurl = sgLinkRoot + r;

			matches = r.match(/repos\/(.+)/);

			if (matches)
				repo = matches[1];
		}
		else
			ln += '/repos/' + startRepo;

		ln += activity.link;

		
		
		a = $("<a>").attr("href", ln);
		hasLink = true;

		var matches = activity.link.match(/\/(workitem|changeset).html\?recid=([a-z0-9]+)/);

		if (matches)
		{
			var thing = matches[2];
			var type = matches[1];
			var rels = $('#relations');
			var field = 'other';
  
			if (type == 'changeset')
				_actCsHover.addHover(a, thing, null, null, repurl);
			else 
				_actWiHover.addHover(a, thing);

			if (type == 'changeset')
			{
				rels = $('#csrelations');
				field = 'commit';
			}

			if (rels)
			{
				li.draggable(
					{
						disabled: ! window.editMode,
						helper: 'clone'
					}
				);

				var rel = {};
				rel[field] = thing;
				rel.repo = repo;
				li.data('rel', rel );
			}
		}
	} 
	
	if (activity.action != undefined) {
		var act_txt = activity.action + ": ";
		if (hasLink) {
			a.text(act_txt);
			p.append(a);
		}
		else
		{
			p.append(act_txt);
		}
	}

	var el = null;

	if (hasLink && (activity.action == undefined))
	{
		a.text(activity.what);
		el = a;
	}
	else
	{
		var sp = $("<span />").text(activity.what);
		el = sp;
	}

	el.html(vCore.createLinks($.trim(el.text())));
	el.html(el.html().replace(/(\r\n|\n)/g, "<br />"));
	p.append(el);
	
	li.append(p);

	p = $("<p>");
	p.addClass('actsig');

	var d = new Date(parseInt(activity.when));
	var who = activity.email || activity.who || '';
	p.text(_shortWho(who));
	p.append($('<br>'));

	p.append(shortDateTime(d));

	li.append(p);

	return (li);
}

function listActivity(callback) {
	if (callback && (typeof(callback) != 'function'))
		callback = null;

	if (!_showActivity()) {
		if (callback)
			callback();
		window.setTimeout(listActivity, 30000);
		return;
	}

	if (vCore.ajaxCallCount > 0)
	{
		++activityTries;

		if (activityTries < 60)
		{
			if (callback)
				callback();
			window.setTimeout(listActivity, 500);
			return;
		}		
	}

	activityTries = 0;

	var listUrl = sgCurrentRepoUrl + "/activity.json";

	if (_filterActivity() && window.sgUserName)
	{
		listUrl = sgCurrentRepoUrl + "/activity/" + sgUserName + ".json";
		$('#linkactfeed').attr('href', sgCurrentRepoUrl + "/activity/" + sgUserName + ".xml");
	}
	else
		$('#linkactfeed').attr('href', sgCurrentRepoUrl + "/activity.xml");

	vCore.ajax( {
		url : listUrl,
		dataType : 'json',
		cache : true,
		reportErrors: false,

		complete : function(xhr, textStatus) {
			if (callback)
				callback();
			window.setTimeout(listActivity, 30000);
		},

		success : function(data, status, xhr) {
			if ((status != "success") || (!data)) {
				return;
			}

			var uls = $('#activitylist ul');
			var ul = false;

			if (uls.length > 0) {
				ul = $(uls[0]);
			} else {
				ul = $(document.createElement("ul"));
				$('#activitylist').append(ul);
			}

			ul.empty();

			$.each(data, function(index, activity) {
				ul.append( activityItem(activity) );
			});

			_actPager.init('#activitylist', '#activitynav');
		}

	});

}

var _actPager = {
	box : false,
	curTop : 0,

	init : function(ctr, nav) {
		this.box = $(ctr);
		this.nav = $(nav);
		this.box.attr('overflow', 'hidden');
		this.alist = $(ctr + ' ul')[0];

		var pager = this;

		var prevButton = $('#prevActivity');
		var nextButton = $('#nextActivity');

		prevButton.click
		(
			function(e) 
			{
				e.stopPropagation();
				e.preventDefault();
				pager.backUp();
			}
		);

		nextButton.click
		(
			function(e) 
			{
				e.stopPropagation();
				e.preventDefault();

				pager.curTop = nextButton.data('hidingAfter');
				pager.redisplay();
			}
		);

		pager.redisplay();
	},

	redisplay : function() {
		if (! this.box) 
		{ 
			return; 
		}

		var top = this.box.offset().top;
		var scrollTop = $(window).scrollTop();
		var wheight = windowHeight();
		var bheight = wheight - top - 40 + scrollTop;
		var hidingAfter = -1;
		var pager = this;
		var prevButton = $('#prevActivity');
		var nextButton = $('#nextActivity');

		this.box.height(bheight);
		
		$(this.alist).children('li').each(function(idx, li) {
			if ((idx < pager.curTop) || (hidingAfter >= 0)) {
				$(li).hide();
			} else {
				$(li).show();

				var bottom = $(li).offset().top + $(li).height() - top;

				if (bottom >= bheight) {
					$(li).hide();

					if (hidingAfter < 0)
						hidingAfter = idx;
				}
			}
		});

		if (pager.curTop > 0) 
		{
			prevButton.removeAttr('disabled');
			prevButton.find('img').show();
		}
		else
		{
			prevButton.attr('disabled', 'disabled');
			prevButton.find('img').hide();
		}

		if (hidingAfter >= 0) 
		{
			nextButton.removeAttr('disabled');
			nextButton.find('img').show();
			nextButton.data('hidingAfter', hidingAfter);
		}
		else
		{
			nextButton.attr('disabled', 'disabled');
			nextButton.find('img').hide();
		}

		pager.nav.show();
	},

	backUp : function() {
		var top = this.box.offset().top;
		var wheight = windowHeight();
		var bheight = wheight - top - 30;
		var hidingAfter = -1;
		var pager = this;
		var tooFar = false;
		var i;

		this.box.height(bheight);

		var els = $(this.alist).children('li');

		i = this.curTop - 1;
		var canary = $(els[i]);

		this.curTop = 0;

		while ((i > 0) && (!tooFar)) {
			var testee = els[i];
			$(testee).show();

			var bottom = canary.offset().top + canary.height() - top;

			if (bottom >= bheight) {
				this.curTop = i + 1;
				break;
			}

			--i;
		}

		this.redisplay();
	}
};
function _setShowActivity(show) {
	var cname = vCore.getDefaultCookieName();
	vCore.setCookieValueForKey(cname, "showActivity", show, 30);
	
	sgShowActivity = show;

	if (show)
	{
	    $('#menushowactvity').addClass("checked");
		$('#menufilteractivity').show();
	}
	else
	{
	    $('#menushowactvity').removeClass("checked");
		$('#menufilteractivity').hide();
	}

	showState = show;
}

function _showActivity() {
	if (showState === null)
	{
		var cname = vCore.getDefaultCookieName();
		var show = vCore.getCookieValueForKey(cname, "showActivity", false);
		showState = (show && (show != "false")); // cookies stringify
	}
	
	return( showState );
}

function _filterActivity(setfilter) 
{
	var cname = vCore.getDefaultCookieName();
	
	if (setfilter !== undefined)
	{
		vCore.setCookieValueForKey(cname, "filterActivity", setfilter, 30);


		if (setfilter)
			$('#menufilteractivity').addClass("checked");
		else
			$('#menufilteractivity').removeClass("checked");
	}

	var v = vCore.getCookieValueForKey(cname, "filterActivity", false);
	
	return(v && (v != 'false'));
}

function hideActivity() 
{
	$('#activity').width(0);
	$('#activity').hide();
	$('#activity').trigger('resize');
	$('#activity').trigger('repaintGraph');
	showState = false;
}

function displayActivity() 
{
	$('#activity').width(214);
	$('#activity').show();
	$('#activity').trigger('resize');
	$('#activity').trigger('repaintGraph');
	showState = true;
}

function setActivityHeight()
{
	var wHeight = windowHeight();
	var top = $("#activity").offset().top;
	var actHeight = wHeight - top;
	
	// Make sure the size actually changes so we aren't 
	// sending an unnecessary resize event (ahem... IE)
	if (actHeight != $("#activity").height())
	{
		$("#activity").css( { height:actHeight } );
	}
}

$(document).ready(function() {
	setActivityHeight();
	
	$(window).resize(function() { 
		setActivityHeight(); 
		_actPager.redisplay();
	});

	var cleanUpIcon = function()
	{
		var i = $('#imgrefreshact').attr('src', sgStaticLinkRoot + "/img/refresh.png");
	};

	$("#linkrefreshact").click(function(e) {
		e.preventDefault();
		e.stopPropagation();

		var i = $('#imgrefreshact').attr('src', sgStaticLinkRoot + "/img/smallTealProgress.gif");
		listActivity(cleanUpIcon);
	});

	_actCsHover = new hoverControl(fetchChangesetHover);
	_actWiHover = new hoverControl(fetchWorkItemHover);

	if (_showActivity()) {
		displayActivity();
		window.setTimeout(listActivity, 1000);
	} else {
		hideActivity();
	}

});
